Small Demo demonstrating BLE Advertising

Dependencies:   BLE_API X_NUCLEO_IDB0XA1 mbed

Fork of BLE_HeartRate_IDB0XA1 by ST

Revision:
29:8eb46b976f0f
Parent:
28:114eaad388c1
--- a/main.cpp	Sun Jan 08 23:13:25 2017 +0000
+++ b/main.cpp	Sat May 19 15:53:19 2018 +0000
@@ -1,5 +1,5 @@
 // N05_Advertising: Tutorial for demonstration of simple advertising
 // Program has been tested on nRF51822-DK
  
 #include "bricks/bricks.h"
 
@@ -33,7 +33,7 @@
    void cbSetup(O&o)                   // setup calback (after BLE init)
    {
       device(o,DEVICE_NAME);           // setup device name
-      name(o,"N05#1.0 Advertise");     // add name to device
+      name(o,"S05#1.0 Advertise");     // add name to device
       data(o,AdvData,sizeof(AdvData)); // advertising user data
 
       onDisconnect(o,cbDisconnect);    // setup disconnection callback
@@ -1,5 +1,5 @@
-// N05_Advertising: Tutorial for demonstration of simple advertising
-// Program has been tested on nRF51822-DK
+// S05_Advertising: Tutorial for demonstration of simple advertising
+// Program has been tested on NUCLEO-L476RG
  
 #include "bricks/bricks.h"